@@ -26,7 +26,7 @@ def getModel(engine):
         id = Column(Integer, Sequence('testrunner_id_seq'), primary_key=True)
         name = Column(Unicode(256), index=True )
         last_run = Column(DateTime())
-        run = relation('Run', backref='run_id', passive_deletes=True, cascade='all, delete, delete-orphan')
+        run = relation('Run', backref='run_id', cascade='all, delete, delete-orphan')
 
 
     class Run(Base):
@@ -42,7 +42,7 @@ def getModel(engine):
         link = Column(String(256))
         description = Column(TEXT)
         run_ok = Column(Boolean, default=False)
-        result = relation('Result', backref='result_id', passive_deletes=True, cascade='all, delete, delete-orphan')
+        result = relation('Result', backref='result_id', cascade='all, delete, delete-orphan')
 
 
     class Result(Base):
